package com.chelvc.framework.wechat;

import java.util.Map;

/**
 * 微信支付操作接口
 *
 * @author Woody
 * @date 2024/6/19
 */
public interface WechatPaymentHandler {
    /**
     * 判断是否支持指定应用
     *
     * @param name 应用名称
     * @return true/false
     */
    boolean supports(String name);

    /**
     * 判断是否指定渠道
     *
     * @param name    应用名称
     * @param channel 支付渠道
     * @return true/false
     */
    boolean isChannel(String name, PayChannel channel);

    /**
     * 判断是否是指定商户
     *
     * @param name     应用名称
     * @param merchant 商户标识
     * @return true/false
     */
    boolean isMerchant(String name, String merchant);

    /**
     * 参数签名
     *
     * @param name       应用名称
     * @param parameters 签名参数
     * @return 签名信息
     */
    String sign(String name, Map<String, String> parameters);

    /**
     * 支付回调参数解析
     *
     * @param name    应用名称
     * @param content 支付回调内容
     * @return 支付回调信息
     */
    WechatPaymentCallback callback(String name, String content);

    /**
     * 微信统一下单
     *
     * @param name    应用名称
     * @param request 支付请求参数
     * @return 微信统一下单信息
     */
    WechatUnifiedOrder unifiedorder(String name, WechatPayRequest request);
}
